| Safe Haskell | None |
|---|
HGamer3D.Data.Vector
Description
Includes the right pieces of the Vect libray of Balazs Komuves. see: http://hackage.haskell.org/package/vect
HGamer3D-Data-0.2.0: Windows Game Engine for the Haskell Programmer - Data Definitions
| Safe Haskell | None |
|---|
HGamer3D.Data.Vector
Description
Includes the right pieces of the Vect libray of Balazs Komuves. see: http://hackage.haskell.org/package/vect